@@ -103,11 +103,12 @@ class WikiReaderState:
     contents of an xml dump line by line
     """
 
-    def __init__(self, file, report_every=100, clear_output=True):
+    def __init__(self, file, verbose, report_every=100, clear_output=True):
         # parameters & input
         self.file = file
         self.report_every = report_every
         self.clear_output = clear_output
+        self.verbose = verbose
 
         # state
         self.reset_state()
@@ -154,10 +155,11 @@ class WikiReaderState:
         self.filtered_articles_seen += 1
         if self.filtered_articles_seen % self.report_every == 0:
             freq = self.filtered_articles_seen / (time.time() - self.start_time)
-            if self.clear_output:
-                clear_output_ipython(wait=True)
-            print("%d articles seen so far. Processing %.3f articles / s : position %r" % (
-                self.filtered_articles_seen, freq, self.file.tell()))
+            if self.verbose:
+                if self.clear_output:
+                    clear_output_ipython(wait=True)
+                print("%d articles seen so far. Processing %.3f articles / s : position %r" % (
+                    self.filtered_articles_seen, freq, self.file.tell()))
 
     def reset_state(self):
         """
@@ -203,7 +205,7 @@ def get_redirection_list(wiki,
                          max_articles=9999999999999999,
                          maxlines=9999999999999999):
 
-    state = WikiReaderState(wiki, report_every=100000000, clear_output=False)
+    state = WikiReaderState(wiki, verbose=True, report_every=100000000, clear_output=False)
     start_element_node = "<%s" % (element)
     end_element_node = "</%s>" % (element)
 
@@ -240,13 +242,13 @@ def get_redirection_list(wiki,
             continue
 
 
-def convert_wiki_to_lines_inner_generator(wiki, skip_cdata, encoding, inner_element, element,
+def convert_wiki_to_lines_inner_generator(wiki, verbose, report_every, skip_cdata, encoding, inner_element, element,
                                           parse_special_pages, skip_templated_lines, maxlines, max_articles, job):
     # do sequential processing
     start, end = job
     if start is not None:
         wiki.seek(start)
-    state = WikiReaderState(wiki, report_every=report_every, clear_output=clear_output)
+    state = WikiReaderState(wiki, verbose=verbose, report_every=report_every, clear_output=clear_output)
     current_article = ''
     start_element_node = "<%s" % (element)
     start_inner_element_node = "<%s" % (inner_element)
@@ -315,7 +317,7 @@ def convert_wiki_to_lines_inner_generator(wiki, skip_cdata, encoding, inner_elem
             state.exit_text()
 
 
-def convert_wiki_to_lines_inner(result_queue, path, *args):
+def convert_wiki_to_lines_inner_queue(result_queue, path, *args):
     with open(path, "rb") as wiki:
         for res in convert_wiki_to_lines_inner_generator(wiki, *args):
             result_queue.put((current_article, state.current_title))
@@ -347,16 +349,18 @@ def convert_wiki_to_lines(wiki,
             jobs.append((so_far, so_far + chunksize))
             so_far = so_far + chunksize
 
-        workers = [Process(target=convert_wiki_to_lines_inner,
-                           args=(result_queue, fname, skip_cdata, encoding, inner_element, element,
+        workers = [Process(target=convert_wiki_to_lines_inner_queue,
+                           args=(result_queue, fname, False, report_every, skip_cdata, encoding, inner_element, element,
                                  parse_special_pages, skip_templated_lines, None, None, job))
                    for job in jobs]
         for worker in workers:
             worker.start()
         done = 0
         articles_emitted = 0
+        state = WikiReaderState(None, verbose=True, report_every=report_every, clear_output=clear_output)
         while True:
             res = result_queue.get()
+            state.mark_seen_filtered_article()
             if res is None:
                 done += 1
                 if done == n_workers:
@@ -372,7 +376,7 @@ def convert_wiki_to_lines(wiki,
             worker.join()
     else:
         # do sequential processing
-        for article, title in convert_wiki_to_lines_inner_generator(wiki, skip_cdata, encoding, inner_element, element,
+        for article, title in convert_wiki_to_lines_inner_generator(wiki, True, report_every, skip_cdata, encoding, inner_element, element,
                                                                     parse_special_pages, skip_templated_lines, maxlines,
                                                                     max_articles, (None, None))
             for subline in line_converter(article, title):
